@@ -662,29 +662,29 @@ class BytesWriter():
         self.valueAry.append(value)
 
     def writeAry(self, func, ary):
-        self.writeInt32(len(ary))
+        self.writeUInt(len(ary))
         for value in ary:
             func(value)
 
     # -----
 
-    def writeInt16(self, value):
-        self.write("h", value)  # -32768 ~ +32767
+    def writeShort(self, value):
+        self.write("h", value)  # int16  -32768 ~ +32767
 
-    def writeUInt16(self, value):
-        self.write("H", value)  # 0 ~ 65535
+    def writeUShort(self, value):
+        self.write("H", value)  # int16   0 ~ 65535
 
-    def writeInt32(self, value):
-        self.write("i", value)  # -2147483648 ~ +2147483647
+    def writeInt(self, value):
+        self.write("i", value)  # int32  -2147483648 ~ +2147483647
 
-    def writeUInt32(self, value):
-        self.write("I", value)  # 0 ~ 4294967295
+    def writeUInt(self, value):
+        self.write("I", value)  # int32   0 ~ 4294967295
 
-    def writeInt64(self, value):
-        self.write("q", value)  # -9223372036854775808 ~ +9223372036854775807
+    def writeLong(self, value):
+        self.write("q", value)  # int64  -9223372036854775808 ~ +9223372036854775807
 
-    def writeUInt64(self, value):
-        self.write("Q", value)  # 0 ~ 18446744073709551615
+    def writeULong(self, value):
+        self.write("Q", value)  # int64   0 ~ 18446744073709551615
 
     def writeFloat(self, value):
         self.write("f", value)
@@ -701,23 +701,23 @@ class BytesWriter():
 
     # -----
 
-    def writeInt16Ary(self, ary):
-        self.writeAry(self.writeInt16, ary)
+    def writeShortAry(self, ary):
+        self.writeAry(self.writeShort, ary)
 
-    def writeUInt16Ary(self, ary):
-        self.writeAry(self.writeUInt16, ary)
+    def writeUShortAry(self, ary):
+        self.writeAry(self.writeUShort, ary)
 
-    def writeInt32Ary(self, ary):
-        self.writeAry(self.writeInt32, ary)
+    def writeIntAry(self, ary):
+        self.writeAry(self.writeInt, ary)
 
-    def writeUInt32Ary(self, ary):
-        self.writeAry(self.writeUInt32, ary)
+    def writeUIntAry(self, ary):
+        self.writeAry(self.writeUInt, ary)
 
-    def writeInt64Ary(self, ary):
-        self.writeAry(self.writeInt64, ary)
+    def writeLongAry(self, ary):
+        self.writeAry(self.writeLong, ary)
 
-    def writeUInt64Ary(self, ary):
-        self.writeAry(self.writeUInt64, ary)
+    def writeULongAry(self, ary):
+        self.writeAry(self.writeULong, ary)
 
     def writeFloatAry(self, ary):
         self.writeAry(self.writeFloat, ary)
